@@ -19,7 +19,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *---------------------------------------------------------------------*/
 
-#include "rlwrap.h"		
+#include "rlwrap.h"
 
 
 #include <stdio.h>
@@ -42,7 +42,7 @@
 # include <sys/ioctl.h>
 #endif
 #if defined(PTYS_ARE_PTMX) && !defined(__CYGWIN32__)
-# include <sys/stropts.h>      /* for I_PUSH */
+# include <sys/stropts.h>	/* for I_PUSH */
 #endif
 
 
@@ -59,105 +59,105 @@
 
 
 
-
+#define O_RWNN  O_RDWR | O_NDELAY | O_NOCTTY
 
 int
 ptytty_get_pty(int *fd_tty, const char **ttydev)
 {
-    int             pfd;
+  int pfd;
 
 #ifdef PTYS_ARE_OPENPTY
-    char            tty_name[sizeof "/dev/pts/????\0"];
+  char tty_name[sizeof "/dev/pts/????\0"];
 
-    if (openpty(&pfd, fd_tty, tty_name, NULL, NULL) != -1) {
-	*ttydev = strdup(tty_name);
-	return pfd;
-    }
+  if (openpty(&pfd, fd_tty, tty_name, NULL, NULL) != -1) {
+    *ttydev = strdup(tty_name);
+    return pfd;
+  }
 #endif
 
 #ifdef PTYS_ARE__GETPTY
-    *ttydev = _getpty(&pfd, O_RDWR | O_NDELAY | O_NOCTTY, 0622, 0);
-    if (*ttydev != NULL)
-	return pfd;
+  *ttydev = _getpty(&pfd, O_RWNN, 0622, 0);
+  if (*ttydev != NULL)
+    return pfd;
 #endif
 
 #ifdef PTYS_ARE_GETPTY
-    char           *ptydev;
+  char *ptydev;
 
-    while ((ptydev = getpty()) != NULL)
-	if ((pfd = open(ptydev, O_RDWR | O_NOCTTY, 0)) >= 0) {
-	    *ttydev = ptydev;
-	    return pfd;
-	}
+  while ((ptydev = getpty()) != NULL)
+    if ((pfd = open(ptydev, O_RWNN, 0)) >= 0) {
+      *ttydev = ptydev;
+      return pfd;
+    }
 #endif
 
 #if defined(HAVE_GRANTPT) && defined(HAVE_UNLOCKPT)
 # if defined(PTYS_ARE_GETPT) || defined(PTYS_ARE_PTMX)
-    {
-	extern char    *ptsname();
+  {
+    extern char *ptsname();
 
 #  ifdef PTYS_ARE_GETPT
-	pfd = getpt();
+    pfd = getpt();
 #  else
-	pfd = open("/dev/ptmx", O_RDWR | O_NOCTTY, 0);
+    pfd = open("/dev/ptmx", O_RWNN, 0);
 #  endif
-	if (pfd >= 0) {
-	    if (grantpt(pfd) == 0	/* change slave permissions */
-		&& unlockpt(pfd) == 0) {	/* slave now unlocked */
-		*ttydev = ptsname(pfd);	/* get slave's name */
-		return pfd;
-	    }
-	    close(pfd);
-	}
+    if (pfd >= 0) {
+      if (grantpt(pfd) == 0	/* change slave permissions */
+	  && unlockpt(pfd) == 0) {	/* slave now unlocked */
+	*ttydev = ptsname(pfd);	/* get slave's name */
+	return pfd;
+      }
+      close(pfd);
     }
+  }
 # endif
 #endif
 
 #ifdef PTYS_ARE_PTC
-    if ((pfd = open("/dev/ptc", O_RDWR | O_NOCTTY, 0)) >= 0) {
-	*ttydev = ttyname(pfd);
-	return pfd;
-    }
+  if ((pfd = open("/dev/ptc", O_RWNN, 0)) >= 0) {
+    *ttydev = ttyname(pfd);
+    return pfd;
+  }
 #endif
 
 #ifdef PTYS_ARE_CLONE
-    if ((pfd = open("/dev/ptym/clone", O_RDWR | O_NOCTTY, 0)) >= 0) {
-	*ttydev = ptsname(pfd);
-	return pfd;
-    }
+  if ((pfd = open("/dev/ptym/clone", O_RWNN, 0)) >= 0) {
+    *ttydev = ptsname(pfd);
+    return pfd;
+  }
 #endif
 
 #ifdef PTYS_ARE_NUMERIC
-    {
-	int             idx;
-	char           *c1, *c2;
-	char            pty_name[] = "/dev/ptyp???";
-	char            tty_name[] = "/dev/ttyp???";
+  {
+    int idx;
+    char *c1, *c2;
+    char pty_name[] = "/dev/ptyp???";
+    char tty_name[] = "/dev/ttyp???";
 
-	c1 = &(pty_name[sizeof(pty_name) - 4]);
-	c2 = &(tty_name[sizeof(tty_name) - 4]);
-	for (idx = 0; idx < 256; idx++) {
-	    snprintf1(c1, strlen(c1), "%d", idx);
-	    snprintf1(c2, strlen(c2), "%d", idx);
-	    if (access(tty_name, F_OK) < 0) {
-		idx = 256;
-		break;
-	    }
-	    if ((pfd = open(pty_name, O_RDWR | O_NOCTTY, 0)) >= 0) {
-		if (access(tty_name, R_OK | W_OK) == 0) {
-		    *ttydev = strdup(tty_name);
-		    return pfd;
-		}
-		close(pfd);
-	    }
+    c1 = &(pty_name[sizeof(pty_name) - 4]);
+    c2 = &(tty_name[sizeof(tty_name) - 4]);
+    for (idx = 0; idx < 256; idx++) {
+      snprintf1(c1, strlen(c1), "%d", idx);
+      snprintf1(c2, strlen(c2), "%d", idx);
+      if (access(tty_name, F_OK) < 0) {
+	idx = 256;
+	break;
+      }
+      if ((pfd = open(pty_name, O_RWNN, 0)) >= 0) {
+	if (access(tty_name, R_OK | W_OK) == 0) {
+	  *ttydev = strdup(tty_name);
+	  return pfd;
 	}
+	close(pfd);
+      }
     }
+  }
 #endif
 #ifdef PTYS_ARE_SEARCHED
-    {
-	const char     *c1, *c2;
-	char            pty_name[] = "/dev/pty??";
-	char            tty_name[] = "/dev/tty??";
+  {
+    const char *c1, *c2;
+    char pty_name[] = "/dev/pty??";
+    char tty_name[] = "/dev/tty??";
 
 # ifndef PTYCHAR1
 #  define PTYCHAR1	"pqrstuvwxyz"
@@ -165,24 +165,24 @@ ptytty_get_pty(int *fd_tty, const char **ttydev)
 # ifndef PTYCHAR2
 #  define PTYCHAR2	"0123456789abcdef"
 # endif
-	for (c1 = PTYCHAR1; *c1; c1++) {
-	    pty_name[(sizeof(pty_name) - 3)] =
-	        tty_name[(sizeof(pty_name) - 3)] = *c1;
-	    for (c2 = PTYCHAR2; *c2; c2++) {
-		pty_name[(sizeof(pty_name) - 2)] =
-		    tty_name[(sizeof(pty_name) - 2)] = *c2;
-		if ((pfd = open(pty_name, O_RDWR | O_NOCTTY, 0)) >= 0) {
-		    if (access(tty_name, R_OK | W_OK) == 0) {
-			*ttydev = strdup(tty_name);
-			return pfd;
-		    }
-		    close(pfd);
-		}
-	    }
+    for (c1 = PTYCHAR1; *c1; c1++) {
+      pty_name[(sizeof(pty_name) - 3)] =
+	tty_name[(sizeof(pty_name) - 3)] = *c1;
+      for (c2 = PTYCHAR2; *c2; c2++) {
+	pty_name[(sizeof(pty_name) - 2)] =
+	  tty_name[(sizeof(pty_name) - 2)] = *c2;
+	if ((pfd = open(pty_name, O_RWNN, 0)) >= 0) {
+	  if (access(tty_name, R_OK | W_OK) == 0) {
+	    *ttydev = strdup(tty_name);
+	    return pfd;
+	  }
+	  close(pfd);
 	}
+      }
     }
+  }
 #endif
-    return -1;
+  return -1;
 }
 
 /*----------------------------------------------------------------------*/
@@ -193,7 +193,7 @@ ptytty_get_pty(int *fd_tty, const char **ttydev)
 int
 ptytty_get_tty(const char *ttydev)
 {
-    return open(ttydev, O_RDWR | O_NOCTTY, 0);
+  return open(ttydev, O_RDWR | O_NOCTTY, 0);
 }
 
 /*----------------------------------------------------------------------*/
@@ -205,36 +205,45 @@ int
 ptytty_control_tty(int fd_tty, const char *ttydev)
 {
 #ifndef __QNX__
-    int             fd;
+  int fd;
 
-    DPRINTF3(DEBUG_TERMIO, "pid: %d, tty fd: %d, dev: %s", getpid(), fd_tty, ttydev);
+  DPRINTF3(DEBUG_TERMIO, "pid: %d, tty fd: %d, dev: %s", getpid(), fd_tty,
+	   ttydev);
 /* ---------------------------------------- */
-    DPRINTF2(DEBUG_TERMIO, "tcgetpgrp(): %d  getpgrp(): %d", tcgetpgrp(fd_tty), getpgrp());
+  DPRINTF2(DEBUG_TERMIO, "tcgetpgrp(): %d  getpgrp(): %d", tcgetpgrp(fd_tty),
+	   getpgrp());
 
 # ifdef HAVE_SETSID
-    {
-      pid_t  ret =  setsid();
-      DPRINTF2(DEBUG_TERMIO, "setsid() returned %d %s", (int) ret, ERRMSG(ret < 0));
-    }
+  {
+    pid_t ret = setsid();
+
+    DPRINTF2(DEBUG_TERMIO, "setsid() returned %d %s", (int)ret,
+	     ERRMSG(ret < 0));
+  }
 # endif
 
 /* ---------------------------------------- */
 # ifdef TIOCNOTTY
-    fd = open("/dev/tty", O_RDWR | O_NOCTTY);
-    DPRINTF1(DEBUG_TERMIO, "Voiding tty associations: previous=%s", fd < 0 ? "no" : "yes");
-    if (fd >= 0) {
-        int ret = ioctl(fd, TIOCNOTTY, NULL);	/* void tty associations */
-	DPRINTF2(DEBUG_TERMIO, "ioctl(..., TIOCNOTTY): %d %s", ret, ERRMSG(ret < 0));
-	close(fd);
-    }
+  fd = open("/dev/tty", O_RDWR | O_NOCTTY);
+  DPRINTF1(DEBUG_TERMIO, "Voiding tty associations: previous=%s",
+	   fd < 0 ? "no" : "yes");
+  if (fd >= 0) {
+    int ret = ioctl(fd, TIOCNOTTY, NULL);	/* void tty associations */
+
+    DPRINTF2(DEBUG_TERMIO, "ioctl(..., TIOCNOTTY): %d %s", ret,
+	     ERRMSG(ret < 0));
+    close(fd);
+  }
 # endif
 /* ---------------------------------------- */
-    fd = open("/dev/tty", O_RDWR | O_NOCTTY);
-    DPRINTF1(DEBUG_TERMIO, "ptytty_control_tty(): /dev/tty has controlling tty? %s", fd < 0 ? "no (good)" : "yes (bad)");
-    if (fd >= 0)
-	close(fd);		/* ouch: still have controlling tty */
-    errno=0;
-    /* ---------------------------------------- */
+  fd = open("/dev/tty", O_RDWR | O_NOCTTY);
+  DPRINTF1(DEBUG_TERMIO,
+	   "ptytty_control_tty(): /dev/tty has controlling tty? %s",
+	   fd < 0 ? "no (good)" : "yes (bad)");
+  if (fd >= 0)
+    close(fd);			/* ouch: still have controlling tty */
+  errno = 0;
+  /* ---------------------------------------- */
 #if defined(PTYS_ARE_PTMX) && defined(I_PUSH)
 /*
  * Push STREAMS modules:
@@ -254,55 +263,60 @@ ptytty_control_tty(int fd_tty, const char *ttydev)
  * through - Geoff Wing
  */
 # ifdef HAVE_ISASTREAM
-    if (isastream(fd_tty) == 1)
+  if (isastream(fd_tty) == 1)
 # endif
-    {
-	DPRINTF0(DEBUG_TERMIO, "Pushing STREAMS modules");
-	ioctl(fd_tty, I_PUSH, "ptem");
-	ioctl(fd_tty, I_PUSH, "ldterm");
-	ioctl(fd_tty, I_PUSH, "ttcompat");
-    }
+  {
+    DPRINTF0(DEBUG_TERMIO, "Pushing STREAMS modules");
+    ioctl(fd_tty, I_PUSH, "ptem");
+    ioctl(fd_tty, I_PUSH, "ldterm");
+    ioctl(fd_tty, I_PUSH, "ttcompat");
+  }
 #endif
 /* ---------------------------------------- */
 # if defined(TIOCSCTTY)
-    fd = ioctl(fd_tty, TIOCSCTTY, NULL);
-    DPRINTF2(DEBUG_TERMIO, "ioctl(..,TIOCSCTTY): %d %s", fd, ERRMSG(fd<0));
+  fd = ioctl(fd_tty, TIOCSCTTY, NULL);
+  DPRINTF2(DEBUG_TERMIO, "ioctl(..,TIOCSCTTY): %d %s", fd, ERRMSG(fd < 0));
 # elif defined(TIOCSETCTTY)
-    fd = ioctl(fd_tty, TIOCSETCTTY, NULL);
-    DPRINTF2(DEBUG_TERMIO, "ioctl(..,TIOCSETCTTY): %d %s", fd, ERRMSG(fd<0));
+  fd = ioctl(fd_tty, TIOCSETCTTY, NULL);
+  DPRINTF2(DEBUG_TERMIO, "ioctl(..,TIOCSETCTTY): %d %s", fd, ERRMSG(fd < 0));
 # else
-    fd = open(ttydev, O_RDWR);
-    DPRINTF2(DEBUG_TERMIO, "tty open%s %s", (fd < 0 ? " failure" : "ed OK"), ERRMSG(fd < 0));
-    if (fd >= 0)
-	close(fd);
+  fd = open(ttydev, O_RDWR);
+  DPRINTF2(DEBUG_TERMIO, "tty open%s %s", (fd < 0 ? " failure" : "ed OK"),
+	   ERRMSG(fd < 0));
+  if (fd >= 0)
+    close(fd);
 # endif
 /* ---------------------------------------- */
-    fd = open("/dev/tty", O_WRONLY);
-    DPRINTF2(DEBUG_TERMIO, "do we have controlling tty now: %s %s", (fd < 0 ? "no (fatal)" : "yes (good)"), ERRMSG(fd < 0));
-    if (fd < 0)
-      mywarn("Could not get controlling terminal for %s", program_name); /* mywarn called from child */
-    else
-      close(fd);
-      
+  fd = open("/dev/tty", O_WRONLY);
+  DPRINTF2(DEBUG_TERMIO, "do we have controlling tty now: %s %s",
+	   (fd < 0 ? "no (fatal)" : "yes (good)"), ERRMSG(fd < 0));
+  if (fd < 0)
+    mywarn("Could not get controlling terminal for %s", program_name);	/* mywarn called from child */
+  else
+    close(fd);
+
 /* ---------------------------------------- */
-    DPRINTF2(DEBUG_TERMIO, "tcgetpgrp(): %d  getpgrp(): %d", tcgetpgrp(fd_tty), getpgrp());
+  DPRINTF2(DEBUG_TERMIO, "tcgetpgrp(): %d  getpgrp(): %d", tcgetpgrp(fd_tty),
+	   getpgrp());
 /* ---------------------------------------- */
-#endif				/* ! __QNX__ */
-    return 0;
+#endif /* ! __QNX__ */
+  return 0;
 }
 
 
-int  ptytty_openpty(int  *amaster,  int *aslave, const char **name) {
+int
+ptytty_openpty(int *amaster, int *aslave, const char **name)
+{
   const char *scrap;
-  
+
   *aslave = -1;
-  *amaster = ptytty_get_pty (aslave, &scrap);
+  *amaster = ptytty_get_pty(aslave, &scrap);
   if (*amaster < 0)
-    myerror("Could not open master pty\n");
-  if (*aslave < 0) 
-    *aslave = ptytty_get_tty (scrap);
+    myerror("Could not open master pty");
   if (*aslave < 0)
-     myerror("Could not open slave pty\n");
+    *aslave = ptytty_get_tty(scrap);
+  if (*aslave < 0)
+    myerror("Could not open slave pty");
   else {
     if (name != NULL)
       *name = scrap;
